@@ -107,12 +107,9 @@ FontFileMakeDir(char *dirName, int size)
     FontDirectoryPtr	dir;
     int			dirlen;
     int			needslash = 0;
-#ifdef FONTDIRATTRIB
     char		*attrib;
     int			attriblen;
-#endif
 
-#ifdef FONTDIRATTRIB
 #if !defined(__UNIXOS2__) && !defined(WIN32)
     attrib = strchr(dirName, ':');
 #else
@@ -126,20 +123,13 @@ FontFileMakeDir(char *dirName, int size)
 	dirlen = strlen(dirName);
 	attriblen = 0;
     }
-#else
-    dirlen = strlen(dirName);
-#endif
     if (dirName[dirlen - 1] != '/')
 #ifdef NCD
     if (dirlen)     /* leave out slash for builtins */
 #endif
 	needslash = 1;
-#ifdef FONTDIRATTRIB
     dir = (FontDirectoryPtr) xalloc(sizeof *dir + dirlen + needslash + 1 +
 				    (attriblen ? attriblen + 1 : 0));
-#else
-    dir = (FontDirectoryPtr) xalloc(sizeof *dir + dirlen + needslash + 1);
-#endif
     if (!dir)
 	return (FontDirectoryPtr)0;
     if (!FontFileInitTable (&dir->scalable, 0))
@@ -156,7 +146,6 @@ FontFileMakeDir(char *dirName, int size)
     dir->directory = (char *) (dir + 1);
     dir->dir_mtime = 0;
     dir->alias_mtime = 0;
-#ifdef FONTDIRATTRIB
     if (attriblen)
 	dir->attributes = dir->directory + dirlen + needslash + 1;
     else
@@ -165,9 +154,6 @@ FontFileMakeDir(char *dirName, int size)
     dir->directory[dirlen] = '\0';
     if (dir->attributes)
 	strcpy(dir->attributes, attrib);
-#else
-    strcpy(dir->directory, dirName);
-#endif
     if (needslash)
 	strcat(dir->directory, "/");
     return dir;
@@ -633,9 +619,7 @@ FontFileAddFontFile (FontDirectoryPtr dir, char *fontName, char *fileName)
     FontScalableExtraPtr    extra;
     FontEntryPtr	    bitmap = 0, scalable;
     Bool		    isscale;
-#ifdef FONTDIRATTRIB
     Bool		    scalable_xlfd;
-#endif
 
     renderer = FontFileMatchRenderer (fileName);
     if (!renderer)
@@ -661,7 +645,6 @@ FontFileAddFontFile (FontDirectoryPtr dir, char *fontName, char *fileName)
 	      (vals.values_supplied & PIXELSIZE_MASK) != PIXELSIZE_ARRAY &&
 	      (vals.values_supplied & POINTSIZE_MASK) != POINTSIZE_ARRAY &&
 	      !(vals.values_supplied & ENHANCEMENT_SPECIFY_MASK);
-#ifdef FONTDIRATTRIB
 #define UNSCALED_ATTRIB "unscaled"
     scalable_xlfd = (isscale &&
 		(((vals.values_supplied & PIXELSIZE_MASK) == 0) ||
@@ -689,7 +672,6 @@ FontFileAddFontFile (FontDirectoryPtr dir, char *fontName, char *fileName)
 		ptr1 = ptr2 + 1;
 	} while (ptr2);
     }
-#endif
     if (!isscale || (vals.values_supplied & SIZE_SPECIFY_MASK))
     {
       /*
