@@ -272,6 +272,11 @@ const char *I810ramdacSymbols[] = {
    NULL
 };
 
+const char *I810shadowFBSymbols[] = {
+    "ShadowFBInit",
+    NULL
+};
+
 #ifdef XF86DRI
 const char *I810drmSymbols[] = {
    "drmAddBufs",
@@ -313,13 +318,6 @@ const char *I810driSymbols[] = {
    NULL
 };
 
-#ifdef XF86DRI
-
-const char *I810shadowFBSymbols[] = {
-    "ShadowFBInit",
-    NULL
-};
-
 const char *I810shadowSymbols[] = {
     "shadowInit",
     "shadowSetup",
@@ -327,9 +325,7 @@ const char *I810shadowSymbols[] = {
     NULL
 };
 
-#endif
-
-#endif /* I830_ONLY */
+#endif 
 
 #ifndef I810_DEBUG
 int I810_DEBUG = (0
@@ -2273,9 +2269,9 @@ I810ScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
 #endif
 
    if (pI810->directRenderingEnabled) {
-      xf86DrvMsg(pScrn->scrnIndex, driFrom, "Direct rendering enabled\n");
+      xf86DrvMsg(pScrn->scrnIndex, X_INFO, "Direct rendering enabled\n");
    } else {
-      xf86DrvMsg(pScrn->scrnIndex, driFrom, "Direct rendering disabled\n");
+      xf86DrvMsg(pScrn->scrnIndex, X_WARNING, "Direct rendering disabled\n");
    }
 
    pScreen->SaveScreen = I810SaveScreen;
